ex_ICLT: Virtual data set for interval censored and left truncated data
Description
The data ex_ICLT is a virtual data set created to show how to utilize the package. ex_ICLT is interval censored and left truncated data. See ex_IC for interval censored data.
Usage
data(ex_ICLT)
Arguments
Format
The data have the following columns:
lowerIC
The lower limit of the censoring interval.
upperIC
The upper limit of the censoring interval.
trunc
The vector of left truncated points.
X1 - X6
The covariate vectors used for variable selection.